@@ -387,7 +387,7 @@ public:
     /// An application or legacy scene delegate may prefer for the scene 
     /// index observer notices generated from its prim insertions, removals, or
     /// invalidations to be consolidated into vectorized batches. Calling this
-    /// will cause subsequent notices to be be queued.
+    /// will cause subsequent notices to be queued.
     /// 
     /// NOTE: This tracks depth internally and is safe to call in nested 
     ///       contexts. It is not safe to call from multiple threads, though.
@@ -402,6 +402,22 @@ public:
     HD_API
     void SceneIndexEmulationNoticeBatchEnd();
 
+    /// Consolidate notices generated by the merging scene index to vectorized
+    /// batches. Calling this will cause subsequent notices to be queued.
+    /// 
+    /// NOTE: This tracks depth internally and is safe to call in nested 
+    ///       contexts. It is not safe to call from multiple threads, though.
+    HD_API
+    void MergingSceneIndexNoticeBatchBegin();
+
+    /// Flushes any queued scene index observer notices from the merging scene
+    /// index and disables further queueing.
+    ///
+    /// NOTE: This tracks depth internally and is safe to call in nested 
+    ///       contexts. It is not safe to call from multiple threads, though.
+    HD_API
+    void MergingSceneIndexNoticeBatchEnd();
+
     HD_API
     std::string GetInstanceName() const;
 
@@ -493,13 +509,16 @@ private:
         HdRprim *rprim;
     };
 
+    class _NoticeBatchingContext;
+
     HdLegacyPrimSceneIndexRefPtr _emulationSceneIndex;
-    HdNoticeBatchingSceneIndexRefPtr _emulationNoticeBatchingSceneIndex;
-    unsigned int _noticeBatchingDepth;
+    std::unique_ptr<_NoticeBatchingContext> _emulationBatchingCtx;
 
     std::unique_ptr<class HdSceneIndexAdapterSceneDelegate> _siSd;
 
     HdMergingSceneIndexRefPtr _mergingSceneIndex;
+    std::unique_ptr<_NoticeBatchingContext> _mergingBatchingCtx;
+
     HdSceneIndexBaseRefPtr _terminalSceneIndex;
 
     struct _TaskInfo {
