@@ -41,6 +41,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 TF_DECLARE_WEAK_PTRS(SdfFileFormat);
 TF_DECLARE_WEAK_AND_REF_PTRS(SdfLayerStateDelegateBase);
 
+class SdfChangeList;
 struct Sdf_AssetInfo;
 
 /// \class SdfLayer 
@@ -1538,6 +1539,8 @@ public:
     SDF_API
     std::set<double> ListAllTimeSamples() const;
     
+    /// \deprecated
+    /// Use SdfAttributeSpec::ListTimeSamples instead.
     SDF_API
     std::set<double> 
     ListTimeSamplesForPath(const SdfPath& path) const;
@@ -1545,21 +1548,32 @@ public:
     SDF_API
     bool GetBracketingTimeSamples(double time, double* tLower, double* tUpper);
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::GetNumTimeSamples instead.
     SDF_API
     size_t GetNumTimeSamplesForPath(const SdfPath& path) const;
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::GetBracketingTimeSamples instead.
     SDF_API
     bool GetBracketingTimeSamplesForPath(const SdfPath& path, 
                                          double time,
                                          double* tLower, double* tUpper);
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::QueryTimeSample instead.
     SDF_API
     bool QueryTimeSample(const SdfPath& path, double time, 
                          VtValue *value=NULL) const;
+
+    /// \deprecated
+    /// Use SdfAttributeSpec::QueryTimeSample instead.
     SDF_API
     bool QueryTimeSample(const SdfPath& path, double time, 
                          SdfAbstractDataValue *value) const;
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::QueryTimeSample instead.
     template <class T>
     bool QueryTimeSample(const SdfPath& path, double time, 
                          T* data) const
@@ -1579,13 +1593,20 @@ public:
         return hasValue && (!outValue.isValueBlock);
     }
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::SetTimeSample instead.
     SDF_API
     void SetTimeSample(const SdfPath& path, double time, 
                        const VtValue & value);
+
+    /// \deprecated
+    /// Use SdfAttributeSpec::SetTimeSample instead.
     SDF_API
     void SetTimeSample(const SdfPath& path, double time, 
                        const SdfAbstractDataConstValue& value);
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::SetTimeSample instead.
     template <class T>
     void SetTimeSample(const SdfPath& path, double time, 
                        const T& value)
@@ -1595,6 +1616,8 @@ public:
         return SetTimeSample(path, time, untypedInValue);
     }
 
+    /// \deprecated
+    /// Use SdfAttributeSpec::EraseTimeSample instead.
     SDF_API
     void EraseTimeSample(const SdfPath& path, double time);
 
@@ -1612,6 +1635,18 @@ public:
 
     // @}
 
+    /// Returns a \ref SdfChangeList containing the minimal edits that would be
+    /// needed to transform this layer to match the contents of the given
+    /// \p layer parameter. If \p processPropertyFields is false, property 
+    /// fields will be ignored during the diff computation. Any differences in 
+    /// fields between properties with the same path in this layer and \p layer
+    /// will not be captured in the returned SdfChangeList.  This can, however,
+    /// avoid potentially expensive data retrieval operations.
+    SDF_API
+    SdfChangeList CreateDiff(
+        const SdfLayerHandle& layer,
+        bool processPropertyFields = true) const;
+
 protected:
     // Private constructor -- use New(), FindOrCreate(), etc.
     // Precondition: _layerRegistryMutex must be locked.
@@ -1858,6 +1893,21 @@ private:
     // invalidation notice.
     void _AdoptData(const SdfAbstractDataRefPtr &newData);
 
+    // Helper function which will process incoming data to this layer in a
+    // generic way. 
+    // If \p processPropertyFields is false, this method will not
+    // consider property spec fields. In some cases, this can avoid expensive
+    // operations which would pull large amounts of data.
+    template<typename DeleteSpecFunc, typename CreateSpecFunc, 
+            typename SetFieldFunc, typename ErrorFunc>
+    void _ProcessIncomingData(const SdfAbstractDataPtr &newData,
+                              const SdfSchemaBase *newDataSchema,
+                              bool processPropertyFields,
+                              const DeleteSpecFunc &deleteSpecFunc,
+                              const CreateSpecFunc &createSpecFunc,
+                              const SetFieldFunc &setFieldFunc,
+                              const ErrorFunc &errorFunc) const;
+
     // Set _data to match data, calling other primitive setter methods to
     // provide fine-grained inverses and notification.  If \p data might adhere
     // to a different schema than this layer's, pass a pointer to it as \p
