@@ -27,6 +27,10 @@ PXR_NAMESPACE_OPEN_SCOPE
 ///
 /// UsdValidationRegistry is a singleton class, which serves as a central
 /// registry to hold / own all validators and validatorSuites by their names.
+/// UsdValidationRegistry is also immortal and its singleton instance is never
+/// destroyed. This is to ensure that all validators and suites registered with
+/// the registry are available throughout the lifetime of the application.
+///
 /// Both Core USD and client-provided validators are registered with the
 /// registry. Validators can be registered and retrieved dynamically, supporting
 /// complex validation scenarios across different modules or plugins.
@@ -100,7 +104,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 ///             }
 ///             return errors;
 ///         };
-///     registry.RegisterValidator(validatorName, stageTaskFn);
+///     registry.RegisterPluginValidator(validatorName, stageTaskFn);
 /// }
 /// ```
 ///
@@ -316,10 +320,12 @@ public:
 
     /// Return true if a UsdValidator is registered with the name \p
     /// validatorName; false otherwise.
+    USD_API
     bool HasValidator(const TfToken &validatorName) const;
 
     /// Return true if a UsdValidatorSuite is registered with the name \p
     /// validatorSuiteName; false otherwise.
+    USD_API
     bool HasValidatorSuite(const TfToken &suiteName) const;
 
     /// Returns a vector of const pointer to UsdValidator corresponding to all
@@ -578,6 +584,12 @@ private:
     mutable std::shared_mutex _mutex;
 };
 
+// Specialize and delete the DeleteInstance function to prevent destruction.
+// This will prevent the singleton instance for UsdValidationRegistry from
+// being destroyed and hence making it immortal.
+template <>
+void TfSingleton<UsdValidationRegistry>::DeleteInstance() = delete;
+
 USD_API_TEMPLATE_CLASS(TfSingleton<UsdValidationRegistry>);
 
 PXR_NAMESPACE_CLOSE_SCOPE
