@@ -42,6 +42,11 @@ class PropertyDefiningKeys(ConstantsGroup):
     USD_VARIABILITY = "usdVariability"
     WIDGET = "widget"
 
+class UserDocConstants(ConstantsGroup):
+    USERDOC_FULL = "userDoc"
+    USERDOC_BRIEF = "userDocBrief"
+    MAX_LENGTH_FOR_BRIEF = 500
+
 def _IsNSPrefixConnectableAPICompliant(nsPrefix):
     return (nsPrefix == UsdShade.Tokens.inputs[:1] or \
             nsPrefix == UsdShade.Tokens.outputs[:1])
@@ -72,7 +77,7 @@ def _CreateAttrSpecFromNodeAttribute(primSpec, prop, primDefForAttrPruning,
             "shader nodes' outputs to not have the \"outputs\" namespace " \
             "prefix." %(propName, propertyNSPrefixOverride))
 
-    attrType = prop.GetTypeAsSdfType()[0]
+    attrType = prop.GetTypeAsSdfType().GetSdfType()
     
     if not Sdf.Path.IsValidNamespacedIdentifier(propName):
         Tf.RaiseRuntimeError("Property name (%s) for schema (%s) is an " \
@@ -121,9 +126,9 @@ def _CreateAttrSpecFromNodeAttribute(primSpec, prop, primDefForAttrPruning,
             attrSpec.hidden = True
 
     if prop.GetHelp():
-        attrSpec.documentation = prop.GetHelp()
+        _SetSchemaUserDocFields(attrSpec, prop.GetHelp())
     elif prop.GetLabel(): # fallback documentation can be label
-        attrSpec.documentation = prop.GetLabel()
+        _SetSchemaUserDocFields(attrSpec, prop.GetLabel())
     if prop.GetPage():
         attrSpec.displayGroup = prop.GetPage()
     if prop.GetLabel():
@@ -165,6 +170,26 @@ def _CreateAttrSpecFromNodeAttribute(primSpec, prop, primDefForAttrPruning,
         attrSpec.SetInfo(PropertyDefiningKeys.CONNECTABILITY, 
                 UsdShade.Tokens.interfaceOnly)
 
+def _SetSchemaUserDocFields(spec, doc):
+    """
+    Sets the user doc custom metadata fields in the generated schema for prim 
+    and attribute specs. 
+    """
+    # Set the "brief" user doc, used for in-context help, e.g. in DCC tools.
+    # If the doc string exceeds a certain length, just use the first sentence.
+    workDoc = ""
+    if len(doc) > UserDocConstants.MAX_LENGTH_FOR_BRIEF:
+        workDoc = doc.partition('.')[0] + '.'
+        # If '.' wasn't found, workDoc will be the entire doc string, so 
+        # instead use the first MAX_LENGTH_FOR_BRIEF chars and append '...'
+        if len(workDoc) > UserDocConstants.MAX_LENGTH_FOR_BRIEF:
+            workDoc = workDoc[:UserDocConstants.MAX_LENGTH_FOR_BRIEF] + "..."
+    else:
+        workDoc = doc
+    spec.customData[UserDocConstants.USERDOC_BRIEF] = workDoc
+    # Set the "long-form" user doc, used when generating HTML schema docs
+    # (example: https://openusd.org/release/user_guides/schemas/index.html)
+    spec.customData[UserDocConstants.USERDOC_FULL] = doc
 
 def UpdateSchemaWithSdrNode(schemaLayer, sdrNode, renderContext="",
         overrideIdentifier=""):
@@ -242,8 +267,8 @@ def UpdateSchemaWithSdrNode(schemaLayer, sdrNode, renderContext="",
         - A "null" value for Widget sdrProperty metadata translates to 
           SdfPropertySpec Hidden metadata.
         - SdrProperty's Help metadata (Label metadata if Help metadata not 
-          provided) translates to SdfPropertySpec's Documentation string 
-          metadata.
+          provided) translates to SdfPropertySpec's userDocBrief and userDoc
+          custom metadata strings.  
         - SdrProperty's Page metadata translates to SdfPropertySpec's
           DisplayGroup metadata.
         - SdrProperty's Label metadata translates to SdfPropertySpec's
@@ -453,7 +478,7 @@ def UpdateSchemaWithSdrNode(schemaLayer, sdrNode, renderContext="",
 
     doc = sdrNode.GetHelp()
     if doc != "":
-        primSpec.documentation = doc
+        _SetSchemaUserDocFields(primSpec, doc)
 
     # gather properties from a prim definition generated by composing apiSchemas
     # provided by apiSchemasForAttrPruning metadata.
@@ -480,23 +505,29 @@ def UpdateSchemaWithSdrNode(schemaLayer, sdrNode, renderContext="",
     if (schemaBaseProvidesConnectability or \
             schemaPropertyNSPrefixOverride is None or \
             _IsNSPrefixConnectableAPICompliant(schemaPropertyNSPrefixOverride)):
-        shaderIdAttrName = Sdf.Path.JoinIdentifier( \
-                [renderContext, sdrNode.GetContext(), 
-                    PropertyDefiningKeys.SHADER_ID])
-        shaderIdAttrSpec = Sdf.AttributeSpec(primSpec, shaderIdAttrName,
-                Sdf.ValueTypeNames.Token, Sdf.VariabilityUniform)
+        # We must add shaderId for all shaderNodes with the same identifier
+        # across all sourceTypes, so that we get appropriate
+        # renderContext:sourceType:shaderId attribute.
+        sdrRegistry = Sdr.Registry()
+        shaderNodesForShaderIdAttrs = [
+            node for node in sdrRegistry.GetShaderNodesByIdentifier(
+                sdrNode.GetIdentifier())]
+        for node in shaderNodesForShaderIdAttrs:
+            shaderIdAttrName = Sdf.Path.JoinIdentifier( \
+                    [renderContext, node.GetContext(), 
+                        PropertyDefiningKeys.SHADER_ID])
+            shaderIdAttrSpec = Sdf.AttributeSpec(primSpec, shaderIdAttrName,
+                    Sdf.ValueTypeNames.Token, Sdf.VariabilityUniform)
 
-        # Since users shouldn't need to be aware of shaderId attribute, we put 
-        # this in "Internal" displayGroup.
-        shaderIdAttrSpec.displayGroup = \
-                PropertyDefiningKeys.INTERNAL_DISPLAY_GROUP
+            # Since users shouldn't need to be aware of shaderId attribute, we 
+            # put this in "Internal" displayGroup.
+            shaderIdAttrSpec.displayGroup = \
+                    PropertyDefiningKeys.INTERNAL_DISPLAY_GROUP
 
-        # Use the identifier if explicitly provided, (it could be a shader node
-        # queried using an explicit path), else use sdrNode's registered 
-        # identifier.
-        nodeIdentifier = overrideIdentifier if overrideIdentifier else \
-                sdrNode.GetIdentifier()
-        shaderIdAttrSpec.default = nodeIdentifier
+            # We are iterating on sdrNodes which are guaranteed to be registered
+            # with sdrRegistry and it only makes sense to add shaderId for these
+            # shader nodes, so directly get the identifier from the node itself.
+            shaderIdAttrSpec.default = node.GetIdentifier()
 
     # Extra attrSpec
     schemaBasePrimDefinition = \
